@@ -14,33 +14,40 @@ const yaml = require('js-yaml')
 module.exports = {
   elements: {
     spinner: '.patternfly-spinner',
-    table: 'table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra',
+    table: '.pf-c-table',
     createPolicyButton: '#create-policy',
     submitCreatePolicyButton: '#create-button-portal-id',
     resetEditor: 'div.creation-view-yaml-header div.editor-bar-button[title="Reset"]',
     yamlMonacoEditor: '.monaco-editor',
-    searchInput: '#search',
-    searchInputClear: '#search ~ .bx--search-close',
-    searchResult: 'table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td',
+    searchInput: '.pf-c-search-input__text',
+    searchInputClear: '.pf-c-search-input__clear',
     resourceFilterBar: 'div.resource-filter-bar > span',
+    resourceFilterBarClear: 'div.resource-filter-bar > span.button',
     filterButton: '#resource-toolbar > div > div > div.resource-filter-button',
     filterMenu: '#resource-toolbar > div.resource-filter-view',
     filterSectionTitles: '#resource-toolbar > div.resource-filter-view > div.filter-sections-container > div > div.filter-section > div.filter-section-title',
     sidePolicyPanel: 'div.bx--modal-container > div.bx--modal-content',
     sidePolicyPanelClose: 'div.bx--modal-container > div.bx--modal-header > button.bx--modal-close',
     sidePolicyPanelClusterLink: 'div.bx--modal-container > div.bx--modal-content a.bx--link',
-    toggleButtonPolicies: '#policies-0',
-    toggleButtonClusterViolations: '#cluster-violations-1',
-    allTableClusterHeading: '.bx--data-table-v2 > thead:nth-child(1) > tr:nth-child(1) > th:nth-child(1) > div:nth-child(1) > span:nth-child(1)',
-    allTablePolicyHeading: '.bx--data-table-v2 > thead:nth-child(1) > tr:nth-child(1) > th:nth-child(2) > div:nth-child(1) > span:nth-child(1)',
-    overflowMenu: 'table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td > div.bx--overflow-menu',
-    overflowViewClusters: 'body > ul.bx--overflow-menu-options > li:nth-child(1) > button',
+    toggleButtonPolicies: '.pf-c-toggle-group__item:first-child .pf-c-toggle-group__button',
+    toggleButtonCluster: '.pf-c-toggle-group__item:last-child .pf-c-toggle-group__button',
+    allTableHeading: '.pf-c-table__button-content .pf-c-table__text, .pf-c-table__column-help .pf-c-table__text',
+    overflowMenuToggle: '.pf-c-table  .pf-c-dropdown__toggle',
+    overflowMenuBox: '.pattern-fly-table-body > tr:nth-child(1) .pf-c-dropdown__menu',
+    overflowViewClusters: '.pattern-fly-table-body > tr:nth-child(1) .pf-c-dropdown__menu > li:nth-child(1) > button',
     deleteButton: '.bx--overflow-menu-options__option--danger',
     confirmDeleteButton: '.bx--btn--danger--primary',
     noResource: '.no-resource',
-    summaryInfoContainer: 'div.module-grc-cards > div.card-container-container',
-    summaryDropdown: 'div.module-grc-cards > div:nth-child(1) > div:nth-child(2) > div > div:nth-child(1)',
-    summaryDropdownBox: 'div.module-grc-cards > div:nth-child(1) > div:nth-child(2) > div > div:nth-child(2) > div',
+    summaryCardCount: 'button#summary-toggle .grc-cards-count > .pf-c-label__content',
+    summaryCollapse: 'button#summary-toggle > span.pf-c-accordion__toggle-icon',
+    summaryInfoContainer: 'div.module-grc-cards > dl > dd.grc-cards-container',
+    summaryOptions: 'div.module-grc-cards > dl > div.header-options',
+    summaryDropdown: 'div.module-grc-cards > dl > div.header-options > .pf-c-dropdown > button#grc-cards-toggle',
+    summaryDropdownBox: 'div.module-grc-cards > dl > div.header-options > .pf-c-dropdown > ul > li',
+    summaryCards: 'div.module-grc-cards > dl > dd > div > div',
+    summaryCardsInfo: 'div.module-grc-cards > dl > dd > div > div:nth-child(%s) > div.card-container > div.card-content > div:nth-child(2)',
+    summaryCardsInfo_Empty: 'div.module-grc-cards > dl > dd > div > div:nth-child(%s) > div.card-container > div.card-content > div:nth-child(2) > .empty-violations-strip',
+    summaryCardsInfo_Content: 'div.module-grc-cards > dl > dd > div > div:nth-child(%s) > div.card-container > div.card-content > div:nth-child(2) > div:nth-child(%s)',
     policyNameInput: '#name',
     namespaceDropdown: '.creation-view-controls-container > div > div:nth-child(2) > div.bx--list-box',
     namespaceDropdownBox: '.creation-view-controls-container > div > div:nth-child(2) > div.bx--list-box > div.bx--list-box__menu > div',
@@ -67,15 +74,22 @@ module.exports = {
     controlsDropdownClearValue: '.creation-view-controls-container > div > div:nth-child(7) > div.bx--multi-select.bx--list-box > div.bx--list-box__field > div.bx--list-box__selection[title="Clear selected item"]',
     enforceCheckbox: '#enforce',
     disableCheckbox: '#disabled',
+    createErrorDecoration: '.errorDecoration',
+    createNotification: '.bx--inline-notification__subtitle',
   },
   commands: [{
+    dynamicSelector(selectorRef, ...params) {
+      let selectorStr = this.elements[selectorRef].selector
+      params.forEach(param => selectorStr = selectorStr.replace('%s', param))
+      return selectorStr
+    },
     createTestPolicy,
+    checkCreateNotification,
     testCreateCustomSelections,
     testDetailsPage,
     testFilters,
-    testPolicySidePanel,
     updateYamlEditor,
-    verifyPagination,
+    // verifyPagination,
     verifyPolicyTable,
     verifySummary,
     verifyTable,
@@ -83,110 +97,109 @@ module.exports = {
   }],
   compareTemplate: compareTemplate
 }
-function verifySummary(browser, url) {
-  this.waitForElementVisible('button.collapse > span.collapse-button')
+function verifySummary(url) {
+  this.waitForElementVisible('@summaryCollapse')
   this.waitForElementVisible('@summaryInfoContainer')
+  // Collapse the cards (both the cards and the dropdown should disappear)
   this.navigate(url + '?card=false&index=0')
   this.waitForElementNotPresent('@summaryInfoContainer')
+  this.waitForElementNotPresent('@summaryOptions')
+  // Expand the cards
   this.navigate(url + '?card=true&index=0')
   this.waitForElementVisible('@summaryInfoContainer')
-  //standards summary
+  // Standards summary
   this.waitForElementVisible('@summaryDropdown')
   this.click('@summaryDropdown')
-  browser.pause(1000)//wait 1s for every click
-  //Categories summary
+  // Select 'Categories' in the cards dropdown
   this.click('@summaryDropdownBox:nth-child(1)')
-  browser.pause(1000)
-  checkPolicySummaryCards.call(this, browser)
-  browser.pause(1000)//wait 1s for checkPolicySummaryCards func
-  //Standards summary
+  checkPolicySummaryCards(this)
+  // Select 'Standards' in the cards dropdown
   this.click('@summaryDropdown')
-  browser.pause(1000)
   this.click('@summaryDropdownBox:nth-child(2)')
-  browser.pause(1000)
-  checkPolicySummaryCards.call(this, browser)
+  checkPolicySummaryCards(this)
 }
 function checkPolicySummaryCards(browser) {
-  browser.elements('css selector', 'div.module-grc-cards > div:nth-child(2) > div', (cards) => {
-    for (let cardNum = 1; cardNum < cards.value.length + 1; cardNum++) {
-      for (let i = 1; i <= 2; i++) {
-        const cardInfo = `div.module-grc-cards > div:nth-child(2) > div:nth-child(${cardNum}) > div > div > div:nth-child(2)`
-        this.waitForElementVisible(cardInfo)
-        browser.element('css selector', cardInfo + ' > .empty-violations-strip', function (result) {
-          if (result.value === false) {
-            this.click(cardInfo + ` > div:nth-child(${i})`)
-            browser.pause(1000)
-            browser.element('css selector', '.resource-filter-bar > span.button', function (result2) {
-              if (result2.value !== false) {
-                //first card of each category is cluster (no drop-down), second is policy
-                verifyTable(browser, (i % 2 !== 0))
-                this.click('div.resource-filter-bar > span.button')
-                browser.pause(1000)//wait 1s for cleaning resource filters
+  // Get all cards and iterate over them
+  browser.api.elements('@summaryCards', (cards) => {
+    const numCards = cards.value.length
+    // Check number displayed matches number of cards
+    browser.expect.element('@summaryCardCount').text.to.equal(numCards.toString())
+    for (let cardNum = 1; cardNum <= numCards; cardNum++) {
+      const cardInfo = browser.dynamicSelector('summaryCardsInfo', cardNum)
+      browser.waitForElementVisible(cardInfo)
+      // Check to make sure it's not a card with no violations
+      const emptyCard = browser.dynamicSelector('summaryCardsInfo_Empty', cardNum)
+      browser.api.element('css selector', emptyCard, (result) => {
+        if (result.status === -1) {
+          // Verify and iterate over two violation links on card: 1) Cluster 2) Policy
+          browser.expect.element(cardInfo).to.have.property('childElementCount').equals(2)
+          for (let i = 1; i <= 2; i++) {
+            browser.waitForElementVisible(browser.dynamicSelector('summaryCardsInfo_Content', cardNum, i))
+            browser.click(browser.dynamicSelector('summaryCardsInfo_Content', cardNum, i))
+            // Check to see whether filters were applied on click
+            browser.api.element('@resourceFilterBarClear', (result2) => {
+              if (result2.status !== -1) {
+                // First violation selection of each card is cluster (no expandable row), second is policy
+                verifyTable(browser, i === 1)
+                browser.click('@resourceFilterBarClear')
+                // Clicking a card collapses the cards, so we need to re-expand them
+                browser.expect.element('@summaryInfoContainer').to.not.be.visible
+                browser.click('@summaryCollapse')
+                browser.waitForElementVisible('@summaryInfoContainer')
+              } else {
+                browser.assert.fail(`Filters should have appeared after clicking part ${i} of GRC card ${cardNum} but were not present.`)
               }
             })
           }
-        })
-      }
+        } else {
+          browser.assert.ok(true, `GRC Card ${cardNum} has no violations.`)
+        }
+      })
     }
   })
 }
 function verifyTable(browser, cluster) {
-  browser.element('css selector', 'div.no-resource', function (result) {
-    if (result.status !== -1) {
-      this.waitForElementVisible('div.no-resource')
-    }
-    else {
-      this.waitForElementVisible('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra')
-      if (!cluster) {
-        this.click('button.bx--table-expand-v2__button:nth-of-type(1)')
-        this.waitForElementVisible('tr.bx--expandable-row-v2:nth-of-type(2)')
-        this.click('button.bx--table-expand-v2__button:nth-of-type(1)')
-        this.waitForElementVisible('tr.bx--expandable-row-v2:nth-of-type(2)')
-        this.click('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(9) > div > svg')
-        this.waitForElementVisible('ul.bx--overflow-menu-options.bx--overflow-menu--flip.bx--overflow-menu-options--open')
-        this.click('ul.bx--overflow-menu-options.bx--overflow-menu--flip.bx--overflow-menu-options--open > li:nth-child(1)')
+  browser.api.element('@noResource', (result) => {
+    if (result.status === -1) {
+      browser.waitForElementVisible('@table')
+      // Check side panel
+      browser.click('@overflowMenuToggle')
+      // *** TEMPORARY TEST WITHOUT SIDE PANEL ***
+      // Open overflow, verify it's not "View", and close overflow menu
+      browser.expect.element('@overflowMenuBox').to.be.present
+      if (cluster) {
+        browser.expect.element('@overflowViewClusters').text.to.equal('Launch cluster')
+      } else {
+        browser.expect.element('@overflowViewClusters').text.to.equal('Edit')
       }
-      else {
-        this.click('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(5) > div > svg')
-        this.waitForElementVisible('ul.bx--overflow-menu-options.bx--overflow-menu--flip.bx--overflow-menu-options--open')
-        this.click('ul.bx--overflow-menu-options.bx--overflow-menu--flip.bx--overflow-menu-options--open > li:nth-child(1)')
-      }
-      this.waitForElementVisible('div.bx--modal.is-visible')
-      this.click('button.bx--modal-close')
-      this.waitForElementNotPresent('div.bx--modal.is-visible')
+      browser.click('@overflowMenuToggle')
+      browser.expect.element('@overflowMenuBox').to.not.be.present
     }
   })
 }
 // Test content toggle
 function verifyToggle() {
-  this.click('@toggleButtonClusterViolations')
-  this.waitForElementVisible('@allTableClusterHeading')
-  this.expect.element('@allTableClusterHeading').text.to.equal('Cluster name')
+  // CLUSTER TOGGLE
+  this.click('@toggleButtonCluster')
+  this.waitForElementVisible('@allTableHeading')
+  this.expect.element('@allTableHeading').text.to.equal('Cluster name')
+  // Check to make sure the cluster link redirects to its RHACM cluster page
+  this.expect.element('tbody tr > *:first-child > a').to.have.attribute('href').that.matches(/.*\/multicloud\/clusters\/[a-z0-9-]+\/overview$/)
+  // POLICY TOGGLE
   this.click('@toggleButtonPolicies')
-  this.waitForElementVisible('@allTablePolicyHeading')
-  this.expect.element('@allTablePolicyHeading').text.to.equal('Policy name')
-}
-function verifyPagination() {
-  const pagination = '.bx--pagination'
-  this.waitForElementVisible(pagination)
-  this.click('select[id="bx-pagination-select-resource-table-pagination"] option[value="5"]')
-  this.waitForElementVisible('.bx--pagination__button.bx--pagination__button--forward')
-  this.click('.bx--pagination__button.bx--pagination__button--forward')
-  this.waitForElementVisible('.bx--pagination__button.bx--pagination__button--backward')
-  this.click('.bx--pagination__button.bx--pagination__button--backward')
-  this.click('select[id="bx-pagination-select-resource-table-pagination"] option[value="10"]')
-}
-/* Test side panel */
-function testPolicySidePanel() {
-  this.click('@overflowMenu')
-  this.click('@overflowViewClusters')
-  this.waitForElementVisible('@sidePolicyPanel')
-  this.waitForElementNotPresent('@spinner')
-  this.expect.element('@sidePolicyPanelClusterLink').text.to.equal('Launch cluster')
-  this.expect.element('@sidePolicyPanelClusterLink').to.have.attribute('href').to.startWith('https://console')
-  this.click('@sidePolicyPanelClose')
-  this.waitForElementNotPresent('@sidePolicyPanel')
+  this.waitForElementVisible('@allTableHeading')
+  this.expect.element('@allTableHeading').text.to.equal('Policy name')
 }
+// function verifyPagination() {
+//   const pagination = '.bx--pagination'
+//   this.waitForElementVisible(pagination)
+//   this.click('select[id="bx-pagination-select-resource-table-pagination"] option[value="5"]')
+//   this.waitForElementVisible('.bx--pagination__button.bx--pagination__button--forward')
+//   this.click('.bx--pagination__button.bx--pagination__button--forward')
+//   this.waitForElementVisible('.bx--pagination__button.bx--pagination__button--backward')
+//   this.click('.bx--pagination__button.bx--pagination__button--backward')
+//   this.click('select[id="bx-pagination-select-resource-table-pagination"] option[value="10"]')
+// }
 /* Test policy filters on the policy summary page */
 function testFilters(spec = {}) {
   const headings = [ 'Standards', 'Categories', 'Controls', 'Type' ]
@@ -195,6 +208,7 @@ function testFilters(spec = {}) {
   this.expect.element('@filterMenu').to.be.present
   // Wait for filter menu opening animation to finish
   this.waitForElementVisible('@filterSectionTitles')
+  this.pause(500)
   // Check for proper headings and click checkboxes that match policy
   for (let i = 0; i < headings.length; i++) {
     this.api.element('xpath', `//div[contains(@class,"filter-section-title") and text()="${headings[i]}"]`, (result) => {
@@ -215,9 +229,9 @@ function testFilters(spec = {}) {
     }
   }
   // Expect our policy to still be visible after checking its respective filters
-  this.expect.element('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(2) > a').text.to.contain(spec.policyName)
+  this.expect.element('tbody tr > *:first-child > a').text.to.contain(spec.policyName)
   // Leave and return to the summary page to make sure the filters are still there
-  this.click('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(2) > a')
+  this.click('tbody tr > *:first-child > a')
   this.waitForElementNotPresent('@spinner')
   this.click('.bx--breadcrumb > div:nth-child(1)')
   this.waitForElementNotPresent('@spinner')
@@ -441,27 +455,41 @@ function updateYamlEditor() {
   editYaml(this, 'true', 12, 'disableCheckbox', true)
   editYaml(this, applyTemplate('', 'custom_spec.yaml'), 13, 'templateDropdownInput', true, 'Custom specifications')
 }
+// Check notification on the Create page for a violation
+function checkCreateNotification(expectedNotification='', errExpected=true) {
+  if (errExpected) {
+    // Click "Create" button
+    this.waitForElementVisible('@submitCreatePolicyButton')
+    this.click('@submitCreatePolicyButton')
+    // Check notification
+    this.waitForElementVisible('@createNotification')
+    this.expect.element('@createNotification').text.to.equal(expectedNotification)
+  } else {
+    this.expect.element('@createErrorDecoration').to.not.be.present
+  }
+}
+
 function verifyPolicyTable(name, templateFile) {
   // Parse template file into object
   const file = applyTemplate(name, templateFile)
   const data = yaml.safeLoadAll(file)
   // Verify summary table fields
-  this.expect.element('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(2) > a').text.to.equal(name)
-  this.expect.element('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(3)').text.to.equal(data[0].metadata.namespace)
+  this.expect.element('.pf-c-table > tbody > tr:nth-child(1) > td:nth-child(1) > a').text.to.equal(name)
+  this.expect.element('.pf-c-table > tbody > tr:nth-child(1) > td:nth-child(2)').text.to.equal(data[0].metadata.namespace)
   if (data[0].metadata.annotations['policy.open-cluster-management.io/standards']) {
-    this.expect.element('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(6)').text.to.equal(data[0].metadata.annotations['policy.open-cluster-management.io/standards'])
+    this.expect.element('.pf-c-table > tbody > tr:nth-child(1) > td:nth-child(5)').text.to.equal(data[0].metadata.annotations['policy.open-cluster-management.io/standards'])
   } else {
-    this.expect.element('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(6)').text.to.equal('-')
+    this.expect.element('.pf-c-table > tbody > tr:nth-child(1) > td:nth-child(5)').text.to.equal('-')
   }
   if (data[0].metadata.annotations['policy.open-cluster-management.io/controls']) {
-    this.expect.element('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(7)').text.to.equal(data[0].metadata.annotations['policy.open-cluster-management.io/categories'])
+    this.expect.element('.pf-c-table > tbody > tr:nth-child(1) > td:nth-child(6)').text.to.equal(data[0].metadata.annotations['policy.open-cluster-management.io/categories'])
   } else {
-    this.expect.element('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(7)').text.to.equal('-')
+    this.expect.element('.pf-c-table > tbody > tr:nth-child(1) > td:nth-child(6)').text.to.equal('-')
   }
   if (data[0].metadata.annotations['policy.open-cluster-management.io/categories']) {
-    this.expect.element('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(8)').text.to.equal(data[0].metadata.annotations['policy.open-cluster-management.io/controls'])
+    this.expect.element('.pf-c-table > tbody > tr:nth-child(1) > td:nth-child(7)').text.to.equal(data[0].metadata.annotations['policy.open-cluster-management.io/controls'])
   } else {
-    this.expect.element('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(8)').text.to.equal('-')
+    this.expect.element('.pf-c-table > tbody > tr:nth-child(1) > td:nth-child(7)').text.to.equal('-')
   }
 }
 function testDetailsPage(name, templateFile) {
@@ -469,9 +497,9 @@ function testDetailsPage(name, templateFile) {
   const file = applyTemplate(name, templateFile)
   const data = yaml.safeLoadAll(file)
   // Verify and click policy name in policy table
-  this.expect.element('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(3)').text.to.equal(data[0].metadata.namespace)
-  this.expect.element('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(2) > a').text.to.equal(name)
-  this.click('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(2) > a')
+  this.expect.element('.pf-c-table > tbody > tr:nth-child(1) > td:nth-child(2)').text.to.equal(data[0].metadata.namespace)
+  this.expect.element('.pf-c-table > tbody > tr:nth-child(1) > td:nth-child(1) > a').text.to.equal(name)
+  this.click('.pf-c-table > tbody > tr:nth-child(1) > td:nth-child(1) > a')
   this.waitForElementNotPresent('@spinner')
   // DETAILS TAB TESTS
   // Check policy details
