@@ -10,13 +10,17 @@
 
 module.exports = {
   enterTextInYamlEditor: (el, browser, yaml, time) => {
+    let label = '[]'
+    if (process.env.MANAGED_CLUSTER_NAME !== undefined) {
+      label = `- {key: name, operator: In, values: ["${process.env.MANAGED_CLUSTER_NAME}"]}`
+    }
     el.click('.monaco-editor')
     el.api.execute(
       `const monaco = window.monaco.editor.getModels()[0]\n \
       monaco.pushEditOperations([], \
         [{ \
           range:monaco.getFullModelRange(), \
-          text:'${yaml.replace(/\[TIME\]/g, time).replace(/\r?\n/g, '\\n').replace(/'/g, '\\\'')}' \
+          text:'${yaml.replace(/\[LABEL\]/g, label).replace(/\[TIME\]/g, time).replace(/\r?\n/g, '\\n').replace(/'/g, '\\\'')}' \
         }] \
       )`)
     /* Wait half a second for DOM update */
