@@ -179,7 +179,8 @@ function (_Component) {
           _onChange = _this$props.onChange,
           minDate = _this$props.minDate,
           maxDate = _this$props.maxDate,
-          value = _this$props.value;
+          value = _this$props.value,
+          onClose = _this$props.onClose;
 
       if (datePickerType === 'single' || datePickerType === 'range') {
         var onHook = function onHook(electedDates, dateStr, instance) {
@@ -215,6 +216,7 @@ function (_Component) {
                 _onChange.apply(void 0, arguments);
               }
             },
+            onClose: onClose,
             onReady: onHook,
             onMonthChange: onHook,
             onYearChange: onHook,
@@ -425,6 +427,11 @@ _defineProperty(DatePicker, "propTypes", {
    */
   onChange: PropTypes.func,
 
+  /**
+   * The `close` event handler.
+   */
+  onClose: PropTypes.func,
+
   /**
    * The minimum date that a user can start picking from.
    */
