@@ -442,6 +442,7 @@ module.exports = {
 	"7.3.0": "78.0.3904.130",
 	"7.3.1": "78.0.3904.130",
 	"7.3.2": "78.0.3904.130",
+	"7.3.3": "78.0.3904.130",
 	"8.0.0-beta.1": "79.0.3931.0",
 	"8.0.0-beta.2": "79.0.3931.0",
 	"8.0.0-beta.3": "80.0.3955.0",
@@ -525,6 +526,9 @@ module.exports = {
 	"8.4.0": "80.0.3987.165",
 	"8.4.1": "80.0.3987.165",
 	"8.5.0": "80.0.3987.165",
+	"8.5.1": "80.0.3987.165",
+	"8.5.2": "80.0.3987.165",
+	"8.5.3": "80.0.3987.163",
 	"9.0.0-beta.1": "82.0.4048.0",
 	"9.0.0-beta.2": "82.0.4048.0",
 	"9.0.0-beta.3": "82.0.4048.0",
@@ -595,6 +599,11 @@ module.exports = {
 	"9.1.2": "83.0.4103.122",
 	"9.2.0": "83.0.4103.122",
 	"9.2.1": "83.0.4103.122",
+	"9.3.0": "83.0.4103.122",
+	"9.3.1": "83.0.4103.122",
+	"9.3.2": "83.0.4103.122",
+	"9.3.3": "83.0.4103.122",
+	"9.3.4": "83.0.4103.122",
 	"10.0.0-beta.1": "84.0.4129.0",
 	"10.0.0-beta.2": "84.0.4129.0",
 	"10.0.0-beta.3": "85.0.4161.2",
@@ -612,6 +621,8 @@ module.exports = {
 	"10.0.0-beta.20": "85.0.4183.39",
 	"10.0.0-beta.21": "85.0.4183.39",
 	"10.0.0-beta.23": "85.0.4183.70",
+	"10.0.0-beta.24": "85.0.4183.78",
+	"10.0.0-beta.25": "85.0.4183.80",
 	"10.0.0-nightly.20200209": "82.0.4050.0",
 	"10.0.0-nightly.20200210": "82.0.4050.0",
 	"10.0.0-nightly.20200211": "82.0.4050.0",
@@ -672,6 +683,30 @@ module.exports = {
 	"10.0.0-nightly.20200519": "84.0.4129.0",
 	"10.0.0-nightly.20200520": "84.0.4129.0",
 	"10.0.0-nightly.20200521": "84.0.4129.0",
+	"10.0.0": "85.0.4183.84",
+	"10.0.1": "85.0.4183.86",
+	"10.1.0": "85.0.4183.87",
+	"10.1.1": "85.0.4183.93",
+	"10.1.2": "85.0.4183.98",
+	"10.1.3": "85.0.4183.121",
+	"10.1.4": "85.0.4183.121",
+	"10.1.5": "85.0.4183.121",
+	"11.0.0-beta.1": "86.0.4234.0",
+	"11.0.0-beta.3": "86.0.4234.0",
+	"11.0.0-beta.4": "86.0.4234.0",
+	"11.0.0-beta.5": "86.0.4234.0",
+	"11.0.0-beta.6": "86.0.4234.0",
+	"11.0.0-beta.7": "86.0.4234.0",
+	"11.0.0-beta.8": "87.0.4251.1",
+	"11.0.0-beta.9": "87.0.4251.1",
+	"11.0.0-beta.11": "87.0.4251.1",
+	"11.0.0-beta.12": "87.0.4280.11",
+	"11.0.0-beta.13": "87.0.4280.11",
+	"11.0.0-beta.16": "87.0.4280.27",
+	"11.0.0-beta.17": "87.0.4280.27",
+	"11.0.0-beta.18": "87.0.4280.27",
+	"11.0.0-beta.19": "87.0.4280.27",
+	"11.0.0-beta.20": "87.0.4280.40",
 	"11.0.0-nightly.20200525": "84.0.4129.0",
 	"11.0.0-nightly.20200526": "84.0.4129.0",
 	"11.0.0-nightly.20200529": "85.0.4156.0",
@@ -706,5 +741,30 @@ module.exports = {
 	"11.0.0-nightly.20200804": "86.0.4209.0",
 	"11.0.0-nightly.20200805": "86.0.4209.0",
 	"11.0.0-nightly.20200811": "86.0.4209.0",
-	"11.0.0-nightly.20200812": "86.0.4209.0"
+	"11.0.0-nightly.20200812": "86.0.4209.0",
+	"11.0.0-nightly.20200822": "86.0.4234.0",
+	"11.0.0-nightly.20200824": "86.0.4234.0",
+	"11.0.0-nightly.20200825": "86.0.4234.0",
+	"11.0.0-nightly.20200826": "86.0.4234.0",
+	"12.0.0-nightly.20200827": "86.0.4234.0",
+	"12.0.0-nightly.20200831": "86.0.4234.0",
+	"12.0.0-nightly.20200902": "86.0.4234.0",
+	"12.0.0-nightly.20200903": "86.0.4234.0",
+	"12.0.0-nightly.20200907": "86.0.4234.0",
+	"12.0.0-nightly.20200910": "86.0.4234.0",
+	"12.0.0-nightly.20200911": "86.0.4234.0",
+	"12.0.0-nightly.20200914": "86.0.4234.0",
+	"12.0.0-nightly.20201013": "87.0.4268.0",
+	"12.0.0-nightly.20201014": "87.0.4268.0",
+	"12.0.0-nightly.20201015": "87.0.4268.0",
+	"12.0.0-nightly.20201023": "88.0.4292.0",
+	"12.0.0-nightly.20201026": "88.0.4292.0",
+	"12.0.0-nightly.20201030": "88.0.4306.0",
+	"12.0.0-nightly.20201102": "88.0.4306.0",
+	"12.0.0-nightly.20201103": "88.0.4306.0",
+	"12.0.0-nightly.20201104": "88.0.4306.0",
+	"12.0.0-nightly.20201105": "88.0.4306.0",
+	"12.0.0-nightly.20201106": "88.0.4306.0",
+	"12.0.0-nightly.20201111": "88.0.4306.0",
+	"12.0.0-nightly.20201112": "88.0.4306.0"
 };
\ No newline at end of file
